crikit.utils.tests package — CRIKit2 0.4.3 documentation

# crikit.utils.tests package

## Submodules

## crikit.utils.tests.test_breadcrumb module

crikit.utils.tests.test_breadcrumb.test_breadcrumb()

  Basic breadcrumb testing

crikit.utils.tests.test_breadcrumb.test_breadcrumb_offset()

  Test breadcrumbing when an offset is applied

## crikit.utils.tests.test_general module

crikit.utils.tests.test_general.test_pad_1d()

crikit.utils.tests.test_general.test_pad_1d_0_width()

crikit.utils.tests.test_general.test_pad_2d()

crikit.utils.tests.test_general.test_pad_2d_0_width()

crikit.utils.tests.test_general.test_pad_dual_1d()

crikit.utils.tests.test_general.test_pad_dual_1d_all_0s()

crikit.utils.tests.test_general.test_pad_dual_2d()

## crikit.utils.tests.test_pad_edge_mean module

Tests for crikit.utils.general.pad_edge_mean

crikit.utils.tests.test_pad_edge_mean.test_pad_1d()

crikit.utils.tests.test_pad_edge_mean.test_pad_1d_0_width()

crikit.utils.tests.test_pad_edge_mean.test_pad_2d()

crikit.utils.tests.test_pad_edge_mean.test_pad_2d_0_width()

## Module contents